#
# spec file for package nfoview
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nfoview
Version:        1.99
Release:        1.5
Summary:        Simple Viewer for NFO Files
License:        GPL-3.0-or-later
Group:          Productivity/Text/Utilities
URL:            https://otsaloma.io/nfoview/
Source:         https://github.com/otsaloma/nfoview/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  gettext
BuildRequires:  hicolor-icon-theme
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Recommends:     terminus-font
BuildArch:      noarch

%description
NFO Viewer is a simple viewer for NFO files, which are "ASCII" art in
the CP437 codepage. The advantages of using NFO Viewer instead of a text
editor are preset font and encoding settings, automatic window size and
clickable hyperlinks.

%lang_package

%prep
%autosetup -p1

%build
%make_build

%install
%make_install PREFIX=/usr
%suse_update_desktop_file -r io.otsaloma.nfoview Office Viewer
%find_lang %{name}

%files
%doc AUTHORS.md NEWS.md README.md
%license COPYING
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/metainfo/io.otsaloma.nfoview.appdata.xml
%{_datadir}/applications/io.otsaloma.nfoview.desktop
%{_datadir}/icons/hicolor/*/apps/io.otsaloma.nfoview*.svg
%{_mandir}/man?/*
%{python3_sitelib}/%{name}
%{python3_sitelib}/*.egg-info

%files lang -f %{name}.lang

%changelog
* Sat Nov 25 2023 Dirk Müller <dmueller@suse.com>
- update to 1.99:
  * Export to image functionality disabled for now (I don't know
    how to accomplish this in GTK 4)
  * Switch default font from Cascadia Code to Cascadia Mono (GTK
    4 Cascadia Code would render ligatures, which don't fit well in
    NFO;
  * Mono is basically the same font, but without ligatures)
  * Bump required Python version to 3.8
  * Add Georgian translation
* Thu Oct 27 2022 C J <c.j@tuta.io>
- update to 1.29:
  * Fix font name quoting in Gtk CSS
  * Update translations
* Sun Apr 10 2022 Dirk Müller <dmueller@suse.com>
- update to 1.28.1:
  * Add Chinese (China) translation
  * Add German (Switzerland) translation
  * Add Italian translation
  * Update existing translations
* Thu Apr 30 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.28:
  * Switch default font from Terminus to Cascadia Code as Terminus is
    most commonly a bitmap font, which no longer work with Pango 1.44:
    https://gitlab.gnome.org/GNOME/pango/issues/386
  * Always fall back on the platform default monospace font
  * Add Dutch translation (Heimen Stoffels)
* Thu Apr 23 2020 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.27.1:
  * Fix CSS error with the abnormal weight of the Unscii font
- Drop nfoview-fix-css-font-abnormal-weight.patch
* Mon Mar 16 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.27:
  * New app icon, as full-color and symbolic SVGs.
  * Use the reverse domain name "io.otsaloma.nfoview" for desktop
    file, appdata file and icons.
- Changes from version 1.26.1:
  * Updated translations.
- Modernize spec, use autosetup and python macros.
- Add fdupes BuildRequires and macro, remove duplicate files.
- Drop -lang Recommends: No longer needed, supplements in place.
- Drop hicolor-icon-theme and update-desktop-files
  Requires(post(un)) and macros: No longer needed.
- Add nfoview-fix-css-font-abnormal-weight.patch: Fix CSS error
  with the abnormal weight of the Unscii font.
* Wed Jan 23 2019 bjorn.lie@gmail.com
- Update to version 1.26:
  * Use native file dialogs when available.
- Changes from version 1.25:
  * Add support for building a Flatpak.
  * Add 64x64 and 128x128 icons.
  * Update AppData XML file.
  * Fix build reproducibility.
  * Updated translations.
* Wed Sep 26 2018 Bernhard Wiedemann <bwiedemann@suse.com>
- Update to version 1.24:
  * Avoid error output if not using header bars
  * Set program name
  * Sort input file list to make build reproducible (boo#1041090)
* Sun Nov 12 2017 zaitor@opensuse.org
- Update to version 1.23:
  * Install AppData XML file under /usr/share/metainfo.
  * Drop build dependency on intltool (use gettext instead).
  * Add Donate button to about dialog.
  * Updated translations.
- Replace intltool with gettext BuildRequires following upstreams
  port.
* Sat Sep 30 2017 zaitor@opensuse.org
- Update to version 1.22:
  * Fix window height calculation if line-spacing non-zero.
  * Fix color scheme names not translated.
  * Updated translations.
- Disable desktop_database_post/postun and
  icon_theme_cache_post/postun scriptlets on suse_version >= 1330:
  this functionality is now covered by file triggers and the macros
  expand to %%nil.
* Sat Feb 18 2017 mpluskal@suse.com
- Cleanup specfile:
  * Run spec-cleaner
  * Use pretty archive name
  * Add dependencies for scriplets
* Mon Feb  6 2017 mailaender@opensuse.org
- Update to version 1.21
* Sun Apr 29 2012 lazy.kent@opensuse.org
- Split off language package.
- Build requires python-distribute (for openSUSE >= 12.1).
- Removed check for unsupported openSUSE versions.
* Fri Jul 29 2011 lazy.kent@opensuse.org
- Initial package created - 1.9.5.
- Patch to correct font name and size.
